@@ -52,7 +52,7 @@ class report_pm extends \phpbb\notification\type\pm
 	*
 	* @var string Permission name
 	*/
-	protected $permission = 'm_report';
+	protected $permission = 'm_pm_report';
 
 	/**
 	* Notification option data (for outputting to the user)
@@ -60,18 +60,19 @@ class report_pm extends \phpbb\notification\type\pm
 	* @var bool|array False if the service should use it's default data
 	* 					Array of data (including keys 'id', 'lang', and 'group')
 	*/
-	public static $notification_option = array(
-		'id'	=> 'notification.type.report',
-		'lang'	=> 'NOTIFICATION_TYPE_REPORT',
+	static public $notification_option = [
+		'id'	=> 'notification.type.report_pm',
+		'lang'	=> 'NOTIFICATION_TYPE_REPORT_PM',
 		'group'	=> 'NOTIFICATION_GROUP_MODERATION',
-	);
+	];
 
 	/**
 	* Get the id of the parent
 	*
 	* @param array $pm The data from the pm
+	* @return int The report id
 	*/
-	public static function get_item_parent_id($pm)
+	static public function get_item_parent_id($pm)
 	{
 		return (int) $pm['report_id'];
 	}
@@ -83,12 +84,10 @@ class report_pm extends \phpbb\notification\type\pm
 	*/
 	public function is_available()
 	{
-		$m_approve = $this->auth->acl_getf($this->permission, true);
-
-		return (!empty($m_approve));
+		return $this->config['allow_pm_report'] &&
+			!empty($this->auth->acl_get($this->permission));
 	}
 
-
 	/**
 	* Find the users who want to receive notifications
 	*  (copied from post_in_queue)
@@ -98,11 +97,11 @@ class report_pm extends \phpbb\notification\type\pm
 	*
 	* @return array
 	*/
-	public function find_users_for_notification($post, $options = array())
+	public function find_users_for_notification($post, $options = [])
 	{
-		$options = array_merge(array(
-			'ignore_users'		=> array(),
-		), $options);
+		$options = array_merge([
+			'ignore_users'		=> [],
+		], $options);
 
 		// Global
 		$post['forum_id'] = 0;
@@ -111,7 +110,7 @@ class report_pm extends \phpbb\notification\type\pm
 
 		if (empty($auth_approve))
 		{
-			return array();
+			return [];
 		}
 
 		if (($key = array_search($this->user->data['user_id'], $auth_approve[$post['forum_id']][$this->permission])))
@@ -119,9 +118,9 @@ class report_pm extends \phpbb\notification\type\pm
 			unset($auth_approve[$post['forum_id']][$this->permission][$key]);
 		}
 
-		return $this->check_user_notification_options($auth_approve[$post['forum_id']][$this->permission], array_merge($options, array(
-			'item_type'		=> self::$notification_option['id'],
-		)));
+		return $this->check_user_notification_options($auth_approve[$post['forum_id']][$this->permission], array_merge($options, [
+			'item_type'		=> static::$notification_option['id'],
+		]));
 	}
 
 	/**
@@ -141,12 +140,17 @@ class report_pm extends \phpbb\notification\type\pm
 	*/
 	public function get_email_template_variables()
 	{
-		return array(
-			'AUTHOR_NAME'				=> htmlspecialchars_decode($user_data['username']),
-			'SUBJECT'					=> htmlspecialchars_decode(censor_text($this->get_data('message_subject'))),
+		$user_data = $this->user_loader->get_user($this->get_data('from_user_id'));
 
-			'U_VIEW_REPORT'				=> generate_board_url() . "mcp.{$this->php_ext}?r={$this->item_parent_id}&amp;i=pm_reports&amp;mode=pm_report_details",
-		);
+		return [
+			'AUTHOR_NAME'	=> htmlspecialchars_decode($user_data['username']),
+			'SUBJECT'		=> htmlspecialchars_decode(censor_text($this->get_data('message_subject'))),
+
+			/** @deprecated	3.2.6-RC1	(to be removed in 4.0.0) use {SUBJECT} instead in report_pm.txt */
+			'TOPIC_TITLE'	=> htmlspecialchars_decode(censor_text($this->get_data('message_subject'))),
+
+			'U_VIEW_REPORT'	=> generate_board_url() . "/mcp.{$this->php_ext}?r={$this->item_parent_id}&i=pm_reports&mode=pm_report_details",
+		];
 	}
 
 	/**
@@ -166,11 +170,11 @@ class report_pm extends \phpbb\notification\type\pm
 	*/
 	public function get_title()
 	{
-		$this->user->add_lang('mcp');
+		$this->language->add_lang('mcp');
 
 		$username = $this->user_loader->get_username($this->get_data('reporter_id'), 'no_profile');
 
-		return $this->user->lang(
+		return $this->language->lang(
 			$this->language_key,
 			$username
 		);
@@ -183,7 +187,7 @@ class report_pm extends \phpbb\notification\type\pm
 	*/
 	public function get_reference()
 	{
-		return $this->user->lang(
+		return $this->language->lang(
 			'NOTIFICATION_REFERENCE',
 			censor_text($this->get_data('message_subject'))
 		);
@@ -198,21 +202,21 @@ class report_pm extends \phpbb\notification\type\pm
 	{
 		if ($this->get_data('report_text'))
 		{
-			return $this->user->lang(
+			return $this->language->lang(
 				'NOTIFICATION_REASON',
 				$this->get_data('report_text')
 			);
 		}
 
-		if (isset($this->user->lang[$this->get_data('reason_title')]))
+		if ($this->language->is_set($this->get_data('reason_title')))
 		{
-			return $this->user->lang(
+			return $this->language->lang(
 				'NOTIFICATION_REASON',
-				$this->user->lang[$this->get_data('reason_title')]
+				$this->language->lang($this->get_data('reason_title'))
 			);
 		}
 
-		return $this->user->lang(
+		return $this->language->lang(
 			'NOTIFICATION_REASON',
 			$this->get_data('reason_description')
 		);
@@ -233,25 +237,22 @@ class report_pm extends \phpbb\notification\type\pm
 	*/
 	public function users_to_query()
 	{
-		return array($this->get_data('reporter_id'));
+		return [
+			$this->get_data('from_user_id'),
+			$this->get_data('reporter_id'),
+		];
 	}
 
 	/**
-	* Function for preparing the data for insertion in an SQL query
-	* (The service handles insertion)
-	*
-	* @param array $post Data from submit_post
-	* @param array $pre_create_data Data from pre_create_insert_array()
-	*
-	* @return array Array of data ready to be inserted into the database
+	* {@inheritdoc}
 	*/
-	public function create_insert_array($post, $pre_create_data = array())
+	public function create_insert_array($post, $pre_create_data = [])
 	{
 		$this->set_data('reporter_id', $this->user->data['user_id']);
 		$this->set_data('reason_title', strtoupper($post['reason_title']));
 		$this->set_data('reason_description', $post['reason_description']);
 		$this->set_data('report_text', $post['report_text']);
 
-		return parent::create_insert_array($post, $pre_create_data);
+		parent::create_insert_array($post, $pre_create_data);
 	}
 }
